#!/bin/bash
#
# source: http://www.xsane.org/download/xsane-0.996.tar.gz
#
# maintainer: gmg (monpontet.gerard@neuf.fr)
#

soft='xsane'
softversion='0.996'
packageversion='54.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest

cd $src

chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu" \
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu" \

./configure \
  --prefix=/usr

make -j2
make install DESTDIR=$dest

( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

mkdir -p $dest/usr/share/applications

# Desktop file
cat << "EOF" > $dest/usr/share/applications/xsane.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Xsane
Comment=Scanner application
Exec=xsane
Terminal=0
Type=Application
Icon=xsane
Categories=Application;Office;
EOF

# Description file
mkdir -p $dest/install

cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

     |-----handy-ruler-----------------------------------------------------|
xsane: xsane (Graphical frontend to SANE, Scanner Access Now Easy)
xsane:
xsane: xsane provides a graphical user-interface to control an image
xsane: acquisition device such as a flatbed scanner.  It allows previewing
xsane: and scanning individual images and can be invoked either directly
xsane: from the command-line or through the GIMP image manipulation,
xsane: program.
xsane:
xsane:
xsane:
xsane:
EODESC

# Documentation
mkdir -p $dest/usr/doc/$soft-$softversion
cp -a \
  xsane.ACCELKEYS xsane.AUTHOR xsane.BEGINNERS-INFO xsane.BUGS \
  xsane.CHANGES xsane.COPYING xsane.FAQ xsane.INSTALL xsane.LANGUAGES xsane.LOGO \
  xsane.NEWS xsane.ONLINEHELP xsane.PROBLEMS xsane.REMOVE xsane.ROOT xsane.TODO \
  xsane.VENDOR-STRINGS \
  $dest/usr/doc/$soft-$softversion

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

mkdir -p $dest/usr/lib/gimp/2.0/plug-ins
cd $dest/usr/lib/gimp/2.0/plug-ins
ln -sf /usr/bin/xsane xsane

rm dir -rf $dest/usr/sbin

# Packaging
cd $dest
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.tgz > $package.md5